<a href="https://uwaterloo.ca/networks-lab/"><img src="http://www.johnmclevey.com/assets/img/logo.png" width="125"  align="right" /></a>

# metaknowledge

`metaknowledge` is a Python3 package that simplifies bibliometric research using data from various sources. It reads a directory of plain text files containing meta-data on publications and citations, and writes to a variety of data structures that are suitable for quantitative, network, and text analyses. It handles large datasets (e.g. several million records) efficiently. You can find the [documentation](https://metaknowledge.readthedocs.io/).

## Installing

To install run `python3 setup.py install`
